using System;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Runtime.Serialization;
using IdeaBlade.EntityModel;
using IdeaBlade.Core;
using IdeaBlade.Validation;
using IdeaBlade.Aop;

namespace SimpleSteps {

  /// <summary>
  /// Base class for all entity classes in model.  This class is decorated with the ProvideEntityAspect attribute,
  /// so CodeFirst infrastructure is also injected into sub-classes.
  /// See http://drc.ideablade.com/xwiki/bin/view/Documentation/code-first-entity-base-classes for more information.
  /// </summary>
  [ProvideEntityAspect]
  [DataContract(IsReference = true)]
  public abstract class BaseEntity {

    /// <summary>
    /// A getter will be injected during build.  See http://drc.ideablade.com/xwiki/bin/view/Documentation/code-first-entityaspect for more information.
    /// </summary>
    public EntityAspect EntityAspect { get { return null; } }
  }


  #region NorthwindIBEntities

  /// <summary>
  /// The domain-specific EntityManager for your domain model.
  /// </summary>
  public partial class NorthwindIBEntities : EntityManager {

    public NorthwindIBEntities() : base() { }

    /// <summary>Gets the <see cref="T:EntityQuery"/> for Customer entities. </summary>
    public EntityQuery<Customer> Customers {
      get; set;
    }

    /// <summary>Gets the <see cref="T:EntityQuery"/> for Employee entities. </summary>
    public EntityQuery<Employee> Employees {
      get; set;
    }

    /// <summary>Gets the <see cref="T:EntityQuery"/> for Order entities. </summary>
    public EntityQuery<Order> Orders {
      get; set;
    }

    /// <summary>Gets the <see cref="T:EntityQuery"/> for OrderDetail entities. </summary>
    public EntityQuery<OrderDetail> OrderDetails {
      get; set;
    }

    /// <summary>Gets the <see cref="T:EntityQuery"/> for Product entities. </summary>
    public EntityQuery<Product> Products {
      get; set;
    }

    /// <summary>Gets the <see cref="T:EntityQuery"/> for Supplier entities. </summary>
    public EntityQuery<Supplier> Suppliers {
      get; set;
    }
  }
  #endregion NorthwindIBEntities

  #region Customer class

  /// <summary>The auto-generated Customer class. </summary>
  /// <LongDescription>
  /// test long doc
  /// </LongDescription>
  [DataContract(IsReference=true)]
  [Table("Customer", Schema="dbo")]
  public partial class Customer : BaseEntity {

    #region Data Properties

    /// <summary>Gets or sets the CustomerID. </summary>
    [Key]
    [DataMember]
    [DatabaseGenerated(DatabaseGeneratedOption.None)]
    [Column("CustomerID")]
    [RequiredValueVerifier( ErrorMessageResourceName="Customer_CustomerID")]
    public System.Guid CustomerID {
      get; set;
    }

    /// <summary>Gets or sets the CustomerID_OLD. </summary>
    [DataMember]
    [Column("CustomerID_OLD")]
    [StringLengthVerifier(MaxValue=5, IsRequired=false, ErrorMessageResourceName="Customer_CustomerID_OLD")]
    public string CustomerID_OLD {
      get; set;
    }

    /// <summary>Gets or sets the CompanyName. </summary>
    [DataMember]
    [Column("CompanyName")]
    [StringLengthVerifier(MaxValue=40, IsRequired=true, ErrorMessageResourceName="Customer_CompanyName")]
    public string CompanyName {
      get; set;
    }

    /// <summary>Gets or sets the ContactName. </summary>
    [DataMember]
    [Column("ContactName")]
    [StringLengthVerifier(MaxValue=30, IsRequired=false, ErrorMessageResourceName="Customer_ContactName")]
    public string ContactName {
      get; set;
    }

    /// <summary>Gets or sets the ContactTitle. </summary>
    [DataMember]
    [Column("ContactTitle")]
    [StringLengthVerifier(MaxValue=30, IsRequired=false, ErrorMessageResourceName="Customer_ContactTitle")]
    public string ContactTitle {
      get; set;
    }

    /// <summary>Gets or sets the Address. </summary>
    [DataMember]
    [Column("Address")]
    [StringLengthVerifier(MaxValue=60, IsRequired=false, ErrorMessageResourceName="Customer_Address")]
    public string Address {
      get; set;
    }

    /// <summary>Gets or sets the City. </summary>
    [DataMember]
    [Column("City")]
    [StringLengthVerifier(MaxValue=15, IsRequired=false, ErrorMessageResourceName="Customer_City")]
    public string City {
      get; set;
    }

    /// <summary>Gets or sets the Region. </summary>
    [DataMember]
    [Column("Region")]
    [StringLengthVerifier(MaxValue=15, IsRequired=false, ErrorMessageResourceName="Customer_Region")]
    public string Region {
      get; set;
    }

    /// <summary>Gets or sets the PostalCode. </summary>
    [DataMember]
    [Column("PostalCode")]
    [StringLengthVerifier(MaxValue=10, IsRequired=false, ErrorMessageResourceName="Customer_PostalCode")]
    public string PostalCode {
      get; set;
    }

    /// <summary>Gets or sets the Country. </summary>
    [DataMember]
    [Column("Country")]
    [StringLengthVerifier(MaxValue=15, IsRequired=false, ErrorMessageResourceName="Customer_Country")]
    public string Country {
      get; set;
    }

    /// <summary>Gets or sets the Phone. </summary>
    [DataMember]
    [Column("Phone")]
    [StringLengthVerifier(MaxValue=24, IsRequired=false, ErrorMessageResourceName="Customer_Phone")]
    public string Phone {
      get; set;
    }

    /// <summary>Gets or sets the Fax. </summary>
    [DataMember]
    [Column("Fax")]
    [StringLengthVerifier(MaxValue=24, IsRequired=false, ErrorMessageResourceName="Customer_Fax")]
    public string Fax {
      get; set;
    }

    /// <summary>Gets or sets the RowVersion. </summary>
    [DataMember]
    [Column("RowVersion")]
    [ConcurrencyCheck]
    [ConcurrencyStrategy(ConcurrencyStrategy.AutoIncrement)]
    public System.Nullable<int> RowVersion {
      get; set;
    }
    #endregion Data Properties

    #region Navigation properties

    /// <summary>Gets the Orders. </summary>
    [DataMember]
    [InverseProperty("Customer")]
    public RelatedEntityList<Order> Orders {
      get; set;
    }
    #endregion Navigation properties

    #region EntityPropertyNames
    public partial class EntityPropertyNames : Entity.EntityPropertyNames {
      public const String CustomerID = "CustomerID";
      public const String CustomerID_OLD = "CustomerID_OLD";
      public const String CompanyName = "CompanyName";
      public const String ContactName = "ContactName";
      public const String ContactTitle = "ContactTitle";
      public const String Address = "Address";
      public const String City = "City";
      public const String Region = "Region";
      public const String PostalCode = "PostalCode";
      public const String Country = "Country";
      public const String Phone = "Phone";
      public const String Fax = "Fax";
      public const String RowVersion = "RowVersion";
      public const String Orders = "Orders";
    }
    #endregion EntityPropertyNames
  }
  #endregion Customer class

  #region Employee class

  /// <summary>The auto-generated Employee class. </summary>
  [DataContract(IsReference=true)]
  [Table("Employee", Schema="dbo")]
  public partial class Employee : BaseEntity {

    #region Data Properties

    /// <summary>Gets or sets the EmployeeID. </summary>
    [Key]
    [DataMember]
    [DatabaseGenerated(DatabaseGeneratedOption.Identity)]
    [Column("EmployeeID")]
    [RequiredValueVerifier( ErrorMessageResourceName="Employee_EmployeeID")]
    public int EmployeeID {
      get; set;
    }

    /// <summary>Gets or sets the LastName. </summary>
    [DataMember]
    [Column("LastName")]
    [StringLengthVerifier(MaxValue=30, IsRequired=true, ErrorMessageResourceName="Employee_LastName")]
    public string LastName {
      get; set;
    }

    /// <summary>Gets or sets the FirstName. </summary>
    [DataMember]
    [Column("FirstName")]
    [StringLengthVerifier(MaxValue=30, IsRequired=true, ErrorMessageResourceName="Employee_FirstName")]
    public string FirstName {
      get; set;
    }

    /// <summary>Gets or sets the Title. </summary>
    [DataMember]
    [Column("Title")]
    [StringLengthVerifier(MaxValue=30, IsRequired=false, ErrorMessageResourceName="Employee_Title")]
    public string Title {
      get; set;
    }

    /// <summary>Gets or sets the TitleOfCourtesy. </summary>
    [DataMember]
    [Column("TitleOfCourtesy")]
    [StringLengthVerifier(MaxValue=25, IsRequired=false, ErrorMessageResourceName="Employee_TitleOfCourtesy")]
    public string TitleOfCourtesy {
      get; set;
    }

    /// <summary>Gets or sets the BirthDate. </summary>
    [DataMember]
    [Column("BirthDate")]
    public System.Nullable<System.DateTime> BirthDate {
      get; set;
    }

    /// <summary>Gets or sets the HireDate. </summary>
    [DataMember]
    [Column("HireDate")]
    public System.Nullable<System.DateTime> HireDate {
      get; set;
    }

    /// <summary>Gets or sets the Address. </summary>
    [DataMember]
    [Column("Address")]
    [StringLengthVerifier(MaxValue=60, IsRequired=false, ErrorMessageResourceName="Employee_Address")]
    public string Address {
      get; set;
    }

    /// <summary>Gets or sets the City. </summary>
    [DataMember]
    [Column("City")]
    [StringLengthVerifier(MaxValue=15, IsRequired=false, ErrorMessageResourceName="Employee_City")]
    public string City {
      get; set;
    }

    /// <summary>Gets or sets the Region. </summary>
    [DataMember]
    [Column("Region")]
    [StringLengthVerifier(MaxValue=15, IsRequired=false, ErrorMessageResourceName="Employee_Region")]
    public string Region {
      get; set;
    }

    /// <summary>Gets or sets the PostalCode. </summary>
    [DataMember]
    [Column("PostalCode")]
    [StringLengthVerifier(MaxValue=10, IsRequired=false, ErrorMessageResourceName="Employee_PostalCode")]
    public string PostalCode {
      get; set;
    }

    /// <summary>Gets or sets the Country. </summary>
    [DataMember]
    [Column("Country")]
    [StringLengthVerifier(MaxValue=15, IsRequired=false, ErrorMessageResourceName="Employee_Country")]
    public string Country {
      get; set;
    }

    /// <summary>Gets or sets the HomePhone. </summary>
    [DataMember]
    [Column("HomePhone")]
    [StringLengthVerifier(MaxValue=24, IsRequired=false, ErrorMessageResourceName="Employee_HomePhone")]
    public string HomePhone {
      get; set;
    }

    /// <summary>Gets or sets the Extension. </summary>
    [DataMember]
    [Column("Extension")]
    [StringLengthVerifier(MaxValue=4, IsRequired=false, ErrorMessageResourceName="Employee_Extension")]
    public string Extension {
      get; set;
    }

    /// <summary>Gets or sets the Photo. </summary>
    [DataMember]
    [Column("Photo")]
    public byte[] Photo {
      get; set;
    }

    /// <summary>Gets or sets the Notes. </summary>
    [DataMember]
    [Column("Notes")]
    public string Notes {
      get; set;
    }

    /// <summary>Gets or sets the PhotoPath. </summary>
    [DataMember]
    [Column("PhotoPath")]
    [StringLengthVerifier(MaxValue=255, IsRequired=false, ErrorMessageResourceName="Employee_PhotoPath")]
    public string PhotoPath {
      get; set;
    }

    /// <summary>Gets or sets the ReportsToEmployeeID. </summary>
    [DataMember]
    [ForeignKey("Manager")]
    [Column("ReportsToEmployeeID")]
    public System.Nullable<int> ReportsToEmployeeID {
      get; set;
    }

    /// <summary>Gets or sets the RowVersion. </summary>
    [DataMember]
    [Column("RowVersion")]
    [RequiredValueVerifier( ErrorMessageResourceName="Employee_RowVersion")]
    public int RowVersion {
      get; set;
    }
    #endregion Data Properties

    #region Custom properties

    [Display(Order=0)]
    public string FullName {
      get { return FirstName + " " + LastName; }
    }

    #endregion

    #region Navigation properties

    /// <summary>Gets the DirectReports. </summary>
    [DataMember]
    [Display(AutoGenerateField = false)]
    [InverseProperty("Manager")]
    public RelatedEntityList<Employee> DirectReports {
      get; set;
    }

    /// <summary>Gets or sets the Manager. </summary>
    [DataMember]
    [Display(AutoGenerateField = false)]
    [InverseProperty("DirectReports")]
    public Employee Manager {
      get; set;
    }

    /// <summary>Gets the Orders. </summary>
    [DataMember]
    [Display(AutoGenerateField = false)]
    [InverseProperty("Employee")]
    public RelatedEntityList<Order> Orders {
      get; set;
    }
    #endregion Navigation properties

    #region EntityPropertyNames
    public partial class EntityPropertyNames : Entity.EntityPropertyNames {
      public const String EmployeeID = "EmployeeID";
      public const String LastName = "LastName";
      public const String FirstName = "FirstName";
      public const String Title = "Title";
      public const String TitleOfCourtesy = "TitleOfCourtesy";
      public const String BirthDate = "BirthDate";
      public const String HireDate = "HireDate";
      public const String Address = "Address";
      public const String City = "City";
      public const String Region = "Region";
      public const String PostalCode = "PostalCode";
      public const String Country = "Country";
      public const String HomePhone = "HomePhone";
      public const String Extension = "Extension";
      public const String Photo = "Photo";
      public const String Notes = "Notes";
      public const String PhotoPath = "PhotoPath";
      public const String ReportsToEmployeeID = "ReportsToEmployeeID";
      public const String RowVersion = "RowVersion";
      public const String DirectReports = "DirectReports";
      public const String Manager = "Manager";
      public const String EmployeeTerritories = "EmployeeTerritories";
      public const String Orders = "Orders";
      public const String Territories = "Territories";
    }
    #endregion EntityPropertyNames
  }
  #endregion Employee class

  #region Order class

  /// <summary>The auto-generated Order class. </summary>
  [DataContract(IsReference=true)]
  [Table("Order", Schema="dbo")]
  public partial class Order : BaseEntity {

    #region Data Properties

    /// <summary>Gets or sets the OrderID. </summary>
    [Key]
    [DataMember]
    [DatabaseGenerated(DatabaseGeneratedOption.Identity)]
    [Column("OrderID")]
    [RequiredValueVerifier( ErrorMessageResourceName="Order_OrderID")]
    public int OrderID {
      get; set;
    }

    /// <summary>Gets or sets the CustomerID. </summary>
    [DataMember]
    [ForeignKey("Customer")]
    [Column("CustomerID")]
    public System.Nullable<System.Guid> CustomerID {
      get; set;
    }

    /// <summary>Gets or sets the EmployeeID. </summary>
    [DataMember]
    [ForeignKey("Employee")]
    [Column("EmployeeID")]
    public System.Nullable<int> EmployeeID {
      get; set;
    }

    /// <summary>Gets or sets the OrderDate. </summary>
    [DataMember]
    [Column("OrderDate")]
    public System.Nullable<System.DateTime> OrderDate {
      get; set;
    }

    /// <summary>Gets or sets the RequiredDate. </summary>
    [DataMember]
    [Column("RequiredDate")]
    public System.Nullable<System.DateTime> RequiredDate {
      get; set;
    }

    /// <summary>Gets or sets the ShippedDate. </summary>
    [DataMember]
    [Column("ShippedDate")]
    public System.Nullable<System.DateTime> ShippedDate {
      get; set;
    }

    /// <summary>Gets or sets the Freight. </summary>
    [DataMember]
    [Column("Freight")]
    public System.Nullable<decimal> Freight {
      get; set;
    }

    /// <summary>Gets or sets the ShipName. </summary>
    [DataMember]
    [Column("ShipName")]
    [StringLengthVerifier(MaxValue=40, IsRequired=false, ErrorMessageResourceName="Order_ShipName")]
    public string ShipName {
      get; set;
    }

    /// <summary>Gets or sets the ShipAddress. </summary>
    [DataMember]
    [Column("ShipAddress")]
    [StringLengthVerifier(MaxValue=60, IsRequired=false, ErrorMessageResourceName="Order_ShipAddress")]
    public string ShipAddress {
      get; set;
    }

    /// <summary>Gets or sets the ShipCity. </summary>
    [DataMember]
    [Column("ShipCity")]
    [StringLengthVerifier(MaxValue=15, IsRequired=false, ErrorMessageResourceName="Order_ShipCity")]
    public string ShipCity {
      get; set;
    }

    /// <summary>Gets or sets the ShipRegion. </summary>
    [DataMember]
    [Column("ShipRegion")]
    [StringLengthVerifier(MaxValue=15, IsRequired=false, ErrorMessageResourceName="Order_ShipRegion")]
    public string ShipRegion {
      get; set;
    }

    /// <summary>Gets or sets the ShipPostalCode. </summary>
    [DataMember]
    [Column("ShipPostalCode")]
    [StringLengthVerifier(MaxValue=10, IsRequired=false, ErrorMessageResourceName="Order_ShipPostalCode")]
    public string ShipPostalCode {
      get; set;
    }

    /// <summary>Gets or sets the ShipCountry. </summary>
    [DataMember]
    [Column("ShipCountry")]
    [StringLengthVerifier(MaxValue=15, IsRequired=false, ErrorMessageResourceName="Order_ShipCountry")]
    public string ShipCountry {
      get; set;
    }

    /// <summary>Gets or sets the RowVersion. </summary>
    [DataMember]
    [Column("RowVersion")]
    [RequiredValueVerifier( ErrorMessageResourceName="Order_RowVersion")]
    public int RowVersion {
      get; set;
    }
    #endregion Data Properties

    #region Navigation properties

    /// <summary>Gets or sets the Customer. </summary>
    [DataMember]
    [Display(AutoGenerateField=false)]
    [InverseProperty("Orders")]
    public Customer Customer {
      get; set;
    }

    /// <summary>Gets or sets the Employee. </summary>
    [DataMember]
    [Display(AutoGenerateField = false)]
    [InverseProperty("Orders")]
    public Employee Employee {
      get; set;
    }

    /// <summary>Gets the OrderDetails. </summary>
    [DataMember]
    [Display(AutoGenerateField = false)]
    [InverseProperty("Order")]
    public RelatedEntityList<OrderDetail> OrderDetails {
      get; set;
    }
    #endregion Navigation properties

    #region EntityPropertyNames
    public partial class EntityPropertyNames : Entity.EntityPropertyNames {
      public const String OrderID = "OrderID";
      public const String CustomerID = "CustomerID";
      public const String EmployeeID = "EmployeeID";
      public const String OrderDate = "OrderDate";
      public const String RequiredDate = "RequiredDate";
      public const String ShippedDate = "ShippedDate";
      public const String Freight = "Freight";
      public const String ShipName = "ShipName";
      public const String ShipAddress = "ShipAddress";
      public const String ShipCity = "ShipCity";
      public const String ShipRegion = "ShipRegion";
      public const String ShipPostalCode = "ShipPostalCode";
      public const String ShipCountry = "ShipCountry";
      public const String RowVersion = "RowVersion";
      public const String Customer = "Customer";
      public const String Employee = "Employee";
      public const String OrderDetails = "OrderDetails";
      public const String InternationalOrder = "InternationalOrder";
    }
    #endregion EntityPropertyNames
  }
  #endregion Order class

  #region OrderDetail class

  /// <summary>The auto-generated OrderDetail class. </summary>
  [DataContract(IsReference=true)]
  [Table("OrderDetail", Schema="dbo")]
  public partial class OrderDetail : BaseEntity {

    #region Data Properties

    /// <summary>Gets or sets the OrderID. </summary>
    [Key]
    [DataMember]
    [ForeignKey("Order")]
    [DatabaseGenerated(DatabaseGeneratedOption.None)]
    [Column("OrderID", Order=0)]
    [RequiredValueVerifier( ErrorMessageResourceName="OrderDetail_OrderID")]
    public int OrderID {
      get; set;
    }

    /// <summary>Gets or sets the ProductID. </summary>
    [Key]
    [DataMember]
    [ForeignKey("Product")]
    [DatabaseGenerated(DatabaseGeneratedOption.None)]
    [Column("ProductID", Order=1)]
    [RequiredValueVerifier( ErrorMessageResourceName="OrderDetail_ProductID")]
    public int ProductID {
      get; set;
    }

    /// <summary>Gets or sets the UnitPrice. </summary>
    [DataMember]
    [Column("UnitPrice")]
    [RequiredValueVerifier( ErrorMessageResourceName="OrderDetail_UnitPrice")]
    public decimal UnitPrice {
      get; set;
    }

    /// <summary>Gets or sets the Quantity. </summary>
    [DataMember]
    [Column("Quantity")]
    [RequiredValueVerifier( ErrorMessageResourceName="OrderDetail_Quantity")]
    public short Quantity {
      get; set;
    }

    /// <summary>Gets or sets the Discount. </summary>
    [DataMember]
    [Column("Discount")]
    [RequiredValueVerifier( ErrorMessageResourceName="OrderDetail_Discount")]
    public float Discount {
      get; set;
    }

    /// <summary>Gets or sets the RowVersion. </summary>
    [DataMember]
    [Column("RowVersion")]
    [RequiredValueVerifier( ErrorMessageResourceName="OrderDetail_RowVersion")]
    public int RowVersion {
      get; set;
    }
    #endregion Data Properties

    #region Navigation properties

    /// <summary>Gets or sets the Order. </summary>
    [DataMember]
    [Display(AutoGenerateField = false)]
    [InverseProperty("OrderDetails")]
    public Order Order {
      get; set;
    }

    /// <summary>Gets or sets the Product. </summary>
    [DataMember]
    [Display(AutoGenerateField = false)]
    [InverseProperty("OrderDetails")]
    public Product Product {
      get; set;
    }
    #endregion Navigation properties

    #region EntityPropertyNames
    public partial class EntityPropertyNames : Entity.EntityPropertyNames {
      public const String OrderID = "OrderID";
      public const String ProductID = "ProductID";
      public const String UnitPrice = "UnitPrice";
      public const String Quantity = "Quantity";
      public const String Discount = "Discount";
      public const String RowVersion = "RowVersion";
      public const String Order = "Order";
      public const String Product = "Product";
    }
    #endregion EntityPropertyNames
  }
  #endregion OrderDetail class

  #region Product class

  /// <summary>The auto-generated Product class. </summary>
  [DataContract(IsReference=true)]
  [Table("Product", Schema="dbo")]
  public partial class Product : BaseEntity {

    #region Data Properties

    /// <summary>Gets or sets the ProductID. </summary>
    [Key]
    [DataMember]
    [DatabaseGenerated(DatabaseGeneratedOption.Identity)]
    [Column("ProductID")]
    [RequiredValueVerifier( ErrorMessageResourceName="Product_ProductID")]
    public int ProductID {
      get; set;
    }

    /// <summary>Gets or sets the ProductName. </summary>
    [DataMember]
    [Column("ProductName")]
    [StringLengthVerifier(MaxValue=40, IsRequired=true, ErrorMessageResourceName="Product_ProductName")]
    public string ProductName {
      get; set;
    }

    /// <summary>Gets or sets the SupplierID. </summary>
    [DataMember]
    [ForeignKey("Supplier")]
    [Column("SupplierID")]
    public System.Nullable<int> SupplierID {
      get; set;
    }

    /// <summary>Gets or sets the CategoryID. </summary>
    [DataMember]
    [Column("CategoryID")]
    [Bindable(true, BindingDirection.TwoWay)]
    [Editable(true)]
    [Display(Name = "CategoryID", AutoGenerateField = true)]
    public System.Nullable<int> CategoryID {
      get; set;
    }

    /// <summary>Gets or sets the QuantityPerUnit. </summary>
    [DataMember]
    [Column("QuantityPerUnit")]
    [StringLengthVerifier(MaxValue=20, IsRequired=false, ErrorMessageResourceName="Product_QuantityPerUnit")]
    public string QuantityPerUnit {
      get; set;
    }

    /// <summary>Gets or sets the UnitPrice. </summary>
    [DataMember]
    [Column("UnitPrice")]
    public System.Nullable<decimal> UnitPrice {
      get; set;
    }

    /// <summary>Gets or sets the UnitsInStock. </summary>
    [DataMember]
    [Column("UnitsInStock")]
    public System.Nullable<short> UnitsInStock {
      get; set;
    }

    /// <summary>Gets or sets the UnitsOnOrder. </summary>
    [DataMember]
    [Column("UnitsOnOrder")]
    public System.Nullable<short> UnitsOnOrder {
      get; set;
    }

    /// <summary>Gets or sets the ReorderLevel. </summary>
    [DataMember]
    [Column("ReorderLevel")]
    public System.Nullable<short> ReorderLevel {
      get; set;
    }

    /// <summary>Gets or sets the Discontinued. </summary>
    [DataMember]
    [Column("Discontinued")]
    [DefaultValue(false)]
    [RequiredValueVerifier( ErrorMessageResourceName="Product_Discontinued")]
    public bool Discontinued {
      get; set;
    }

    /// <summary>Gets or sets the DiscontinuedDate. </summary>
    [DataMember]
    [Column("DiscontinuedDate")]
    public System.Nullable<System.DateTime> DiscontinuedDate {
      get; set;
    }

    /// <summary>Gets or sets the RowVersion. </summary>
    [DataMember]
    [Column("RowVersion")]
    [RequiredValueVerifier( ErrorMessageResourceName="Product_RowVersion")]
    public int RowVersion {
      get; set;
    }
    #endregion Data Properties

    #region Navigation properties

    /// <summary>Gets the OrderDetails. </summary>
    [DataMember]
    [Display(AutoGenerateField = false)]
    [InverseProperty("Product")]
    public RelatedEntityList<OrderDetail> OrderDetails {
      get; set;
    }

    /// <summary>Gets or sets the Supplier. </summary>
    [DataMember]
    [Display(AutoGenerateField = false)]
    [InverseProperty("Products")]
    public Supplier Supplier {
      get; set;
    }
    #endregion Navigation properties

    #region EntityPropertyNames
    public partial class EntityPropertyNames : Entity.EntityPropertyNames {
      public const String ProductID = "ProductID";
      public const String ProductName = "ProductName";
      public const String SupplierID = "SupplierID";
      public const String CategoryID = "CategoryID";
      public const String QuantityPerUnit = "QuantityPerUnit";
      public const String UnitPrice = "UnitPrice";
      public const String UnitsInStock = "UnitsInStock";
      public const String UnitsOnOrder = "UnitsOnOrder";
      public const String ReorderLevel = "ReorderLevel";
      public const String Discontinued = "Discontinued";
      public const String DiscontinuedDate = "DiscontinuedDate";
      public const String RowVersion = "RowVersion";
      public const String Category = "Category";
      public const String OrderDetails = "OrderDetails";
      public const String Supplier = "Supplier";
    }
    #endregion EntityPropertyNames
  }
  #endregion Product class

  #region Supplier class

  /// <summary>The auto-generated Supplier class. </summary>
  [DataContract(IsReference=true)]
  [Table("Supplier", Schema="dbo")]
  public partial class Supplier : BaseEntity {

    #region Data Properties

    /// <summary>Gets or sets the SupplierID. </summary>
    [Key]
    [DataMember]
    [DatabaseGenerated(DatabaseGeneratedOption.Identity)]
    [Column("SupplierID")]
    [RequiredValueVerifier( ErrorMessageResourceName="Supplier_SupplierID")]
    public int SupplierID {
      get; set;
    }

    /// <summary>Gets or sets the CompanyName. </summary>
    [DataMember]
    [Column("CompanyName")]
    [StringLengthVerifier(MaxValue=40, IsRequired=true, ErrorMessageResourceName="Supplier_CompanyName")]
    public string CompanyName {
      get; set;
    }

    /// <summary>Gets or sets the ContactName. </summary>
    [DataMember]
    [Column("ContactName")]
    [StringLengthVerifier(MaxValue=30, IsRequired=false, ErrorMessageResourceName="Supplier_ContactName")]
    public string ContactName {
      get; set;
    }

    /// <summary>Gets or sets the ContactTitle. </summary>
    [DataMember]
    [Column("ContactTitle")]
    [StringLengthVerifier(MaxValue=30, IsRequired=false, ErrorMessageResourceName="Supplier_ContactTitle")]
    public string ContactTitle {
      get; set;
    }

    /// <summary>Gets or sets the Address. </summary>
    [DataMember]
    [Column("Address")]
    [StringLengthVerifier(MaxValue=60, IsRequired=false, ErrorMessageResourceName="Supplier_Address")]
    public string Address {
      get; set;
    }

    /// <summary>Gets or sets the City. </summary>
    [DataMember]
    [Column("City")]
    [StringLengthVerifier(MaxValue=15, IsRequired=false, ErrorMessageResourceName="Supplier_City")]
    public string City {
      get; set;
    }

    /// <summary>Gets or sets the Region. </summary>
    [DataMember]
    [Column("Region")]
    [StringLengthVerifier(MaxValue=15, IsRequired=false, ErrorMessageResourceName="Supplier_Region")]
    public string Region {
      get; set;
    }

    /// <summary>Gets or sets the PostalCode. </summary>
    [DataMember]
    [Column("PostalCode")]
    [StringLengthVerifier(MaxValue=10, IsRequired=false, ErrorMessageResourceName="Supplier_PostalCode")]
    public string PostalCode {
      get; set;
    }

    /// <summary>Gets or sets the Country. </summary>
    [DataMember]
    [Column("Country")]
    [StringLengthVerifier(MaxValue=15, IsRequired=false, ErrorMessageResourceName="Supplier_Country")]
    public string Country {
      get; set;
    }

    /// <summary>Gets or sets the Phone. </summary>
    [DataMember]
    [Column("Phone")]
    [StringLengthVerifier(MaxValue=24, IsRequired=false, ErrorMessageResourceName="Supplier_Phone")]
    public string Phone {
      get; set;
    }

    /// <summary>Gets or sets the Fax. </summary>
    [DataMember]
    [Column("Fax")]
    [StringLengthVerifier(MaxValue=24, IsRequired=false, ErrorMessageResourceName="Supplier_Fax")]
    public string Fax {
      get; set;
    }

    /// <summary>Gets or sets the HomePage. </summary>
    [DataMember]
    [Column("HomePage")]
    public string HomePage {
      get; set;
    }

    /// <summary>Gets or sets the RowVersion. </summary>
    [DataMember]
    [Column("RowVersion")]
    [RequiredValueVerifier( ErrorMessageResourceName="Supplier_RowVersion")]
    public int RowVersion {
      get; set;
    }
    #endregion Data Properties

    #region Navigation properties

    /// <summary>Gets the Products. </summary>
    [DataMember]
    [Display(AutoGenerateField = false)]
    [InverseProperty("Supplier")]
    public RelatedEntityList<Product> Products {
      get; set;
    }
    #endregion Navigation properties

    #region EntityPropertyNames
    public partial class EntityPropertyNames : Entity.EntityPropertyNames {
      public const String SupplierID = "SupplierID";
      public const String CompanyName = "CompanyName";
      public const String ContactName = "ContactName";
      public const String ContactTitle = "ContactTitle";
      public const String Address = "Address";
      public const String City = "City";
      public const String Region = "Region";
      public const String PostalCode = "PostalCode";
      public const String Country = "Country";
      public const String Phone = "Phone";
      public const String Fax = "Fax";
      public const String HomePage = "HomePage";
      public const String RowVersion = "RowVersion";
      public const String Products = "Products";
    }
    #endregion EntityPropertyNames
  }
  #endregion Supplier class

}
